%define anolis_release 5
%define dmraid_release 3


Summary: Device-mapper RAID tool and library
Name: dmraid
Version: 1.0.0.rc16
Release: %{anolis_release}%{dist}
License: GPLv2+
URL: http://people.redhat.com/heinzm/sw/dmraid

BuildRequires: gcc make
BuildRequires: libsepol-devel
BuildRequires: libselinux-devel
BuildRequires: systemd-rpm-macros
BuildRequires: device-mapper-event-devel
BuildRequires: device-mapper-devel >= 1.02.02

Requires: kpartx
Requires: systemd
Requires(post): systemd >= 195
Requires: device-mapper >= 1.02.02
Requires: dmraid-libs = %{version}-%{release}

Recommends: dmraid-events = %{version}-%{release}

Conflicts: dmraid < 1.0.0.rc16
Obsoletes: dmraid < 1.0.0.rc16

Source0: https://people.redhat.com/~heinzm/sw/dmraid/src/%{name}-%{version}-%{dmraid_release}.tar.bz2
Source1: anolis-dmraid-activation
Source2: dmraid-activation.service

Patch0: 0001-fix-compilation-error.patch
Patch1: 0002-fix-dmraid-help-coredump-on-aarch64.patch

%description
DMRAID, or device-mapper RAID, is a Linux-based software RAID implementation
that uses the device-mapper framework to manage RAID devices. It is a
collection of tools that is used to create and manage RAID arrays in
Linux operating systems.

DMRAID allows users to create software RAID arrays that can be used for
data redundancy or increased performance in various server and storage
applications. It supports various RAID levels including RAID 0, RAID 1,
RAID 4, RAID 5, and RAID 6.

DMRAID also supports multiple disk formats such as LVM, GPT, and MBR. It
can also detect and manage various RAID hardware devices such as Intel
Matrix RAID, Nvidia nForce RAID, and Promise FastTrak RAID.

The DMRAID tools that are used to manage RAID arrays include dmraid,
which is used to detect RAID devices and create RAID arrays. dmraid also
provides the ability to manage and monitor RAID arrays including rebuilding
arrays, adding or removing disks, and checking for errors.

Other DMRAID tools include dmraid-cleanup, dmraid-activate, dmraid-erase, and
dmraid-info. These tools are used to clean up metadata from failed arrays,
activate arrays, erase metadata from arrays, and provide information about
arrays respectively.

DMRAID is a powerful tool that provides users with a flexible and efficient
way to manage RAID arrays in Linux operating systems. Its support for various
RAID levels and disk formats, as well as its ability to manage hardware RAID
devices, make it a popular choice for storage and server applications.

%package -n dmraid-libs
Summary: System libraries for dmraid
# Splitting libraries out to -libs subpackage
Conflicts: dmraid < 1.0.0.rc16
Obsoletes: dmraid < 1.0.0.rc16

%description -n dmraid-libs
dmraid-libs provides the system libraries for RAID device discovery,
RAID set activation and display of properties for ATARAID volumes.

%package -n dmraid-devel
Summary: Development libraries and headers for dmraid
Requires: dmraid-libs = %{version}-%{release}
Requires: sgpio

%description -n dmraid-devel
dmraid-devel provides a library interface for RAID device discovery,
RAID set activation and display of properties for ATARAID volumes.

%package -n dmraid-events
Summary: Device-mapper event tool (dmevent_tool) and DSO
Requires: sgpio
Requires: device-mapper-event
Requires: dmraid = %{version}-%{release}
Requires: dmraid-libs = %{version}-%{release}

%description -n dmraid-events
Provides a dmeventd DSO and the dmevent_tool to register devices with it
for device monitoring.  All active RAID sets should be manually registered
with dmevent_tool.

%package -n dmraid-events-logwatch
Summary: Logwatch-based email reporting for dmraid
Requires: crontabs
Requires: logwatch
Requires: dmraid-events = %{version}-%{release}

%description -n dmraid-events-logwatch
Provides device failure reporting via logwatch-based email reporting.
Device failure reporting has to be activated manually by activating the
/etc/cron.d/dmeventd-logwatch entry and by calling the dmevent_tool
(see manual page for examples) for any active RAID sets.

%package doc
Summary: Doc files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -n dmraid/%{version}-%{dmraid_release}/dmraid/ -p1

%build
%global _libdir /%{_lib}

%configure --enable-debug --enable-libselinux --enable-libsepol --disable-static_link --enable-led --enable-intel_led
make

%install
install -m 755 -d %{buildroot}{%{_libdir},%{_sbindir},%{_bindir},%{_libdir},%{_includedir}/dmraid/,/etc/cron.d/,/etc/logwatch/conf/services/,/etc/logwatch/scripts/services/,/var/cache/logwatch/dmeventd}
make DESTDIR=%{buildroot} install

(cd %{buildroot}%{_sbindir} ; ln -f dmevent_tool dm_dso_reg_tool)
(cd %{buildroot}%{_mandir}/man8 ; ln -f dmevent_tool.8 dm_dso_reg_tool.8)

install -p -m 644 include/dmraid/*.h %{buildroot}%{_includedir}/dmraid/

install -p -m 755 lib/libdmraid.so %{buildroot}%{_libdir}/libdmraid.so.%{version}
(cd %{buildroot}%{_libdir} ; ln -sf libdmraid.so.%{version} libdmraid.so ; ln -sf libdmraid.so.%{version} libdmraid.so.1)
install -p -m 755 lib/libdmraid-events-isw.so %{buildroot}%{_libdir}/libdmraid-events-isw.so.%{version}
(cd %{buildroot}%{_libdir} ; ln -sf libdmraid-events-isw.so.%{version} libdmraid-events-isw.so ; ln -sf libdmraid-events-isw.so.%{version} libdmraid-events-isw.so.1)

install -p -m 644 logwatch/dmeventd.conf %{buildroot}/etc/logwatch/conf/services/dmeventd.conf
install -p -m 755 logwatch/dmeventd %{buildroot}/etc/logwatch/scripts/services/dmeventd
install -p -m 644 logwatch/dmeventd_cronjob.txt %{buildroot}/etc/cron.d/dmeventd-logwatch
install -p -m 0700 /dev/null %{buildroot}/var/cache/logwatch/dmeventd/syslogpattern.txt

install -d %{buildroot}%{_prefix}/lib/systemd
install -d %{buildroot}%{_unitdir}
install -p -m 755 %{SOURCE1} %{buildroot}%{_prefix}/lib/systemd/anolis-dmraid-activation
install -p -m 444 %{SOURCE2} %{buildroot}%{_unitdir}/dmraid-activation.service

rm -f %{buildroot}%{_libdir}/libdmraid.a
rm -f %{buildroot}%{_prefix}/lib/libdmraid.a

%generate_compatibility_deps

%post
%systemd_post dmraid-activation.service

%preun
%systemd_preun dmraid-activation.service

%postun
%systemd_postun dmraid-activation.service

%files
%dir %{abidir}
%{_sbindir}/dmraid
%{_mandir}/man8/dmraid*
%{abidir}/libdmraid.dump
%{abidir}/libdmraid-events-isw.dump
%{_unitdir}/dmraid-activation.service
%{_prefix}/lib/systemd/anolis-dmraid-activation
%license LICENSE LICENSE_GPL LICENSE_LGPL

%files -n dmraid-libs
%{_libdir}/libdmraid.so.*
%{_libdir}/libdmraid-events-isw.so.*
%license LICENSE LICENSE_GPL LICENSE_LGPL

%files -n dmraid-devel
%{_includedir}/dmraid
%{_libdir}/libdmraid.so
%{_prefix}/lib/libdmraid.so
%{_libdir}/libdmraid-events-isw.so
%doc KNOWN_BUGS TODO doc/dmraid_design.txt
%{_libdir}/device-mapper/libdmraid-events-isw.so

%files -n dmraid-events
%{_sbindir}/dmevent_tool
%{_sbindir}/dm_dso_reg_tool
%{_mandir}/man8/dmevent_tool*
%{_mandir}/man8/dm_dso_reg_tool*

%files -n dmraid-events-logwatch
%config(noreplace) /etc/logwatch/*
%dir /var/cache/logwatch/dmeventd
%config(noreplace) /etc/cron.d/dmeventd-logwatch
%ghost /var/cache/logwatch/dmeventd/syslogpattern.txt

%files doc
%doc CHANGELOG README CREDITS

%changelog 
* Thu Apr 13 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.0.0.rc16-5
- Increase the release number

* Thu Apr 13 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.0.0.rc16-4
- Update some description

* Tue Feb 07 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.0.0.rc16-3
- Add doc package

* Mon Oct 24 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.0.0.rc16-2
- fix dmraid --help coredump on aarch64

* Mon Apr 11 2022 Zhongling He <zhonglingh@linux.alibaba.com> - 1.0.0.rc16-1
- Init package from upstream v1.0.0.rc16
